import classNames from 'classnames';
import React__default, { useRef, useEffect, useState, createElement } from 'react';
import styled from 'styled-components';
import axios from 'axios';

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _taggedTemplateLiteralLoose(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }

  strings.raw = raw;
  return strings;
}

var _templateObject;
var IconContainer = styled.svg(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["\n  transition: all 0.3s;\n  transform: ", ";\n  width: ", ";\n  height: ", ";\n  margin-left: 1.5rem;\n"])), function (props) {
  return props.dropdownOpen ? 'rotate(0deg)' : 'rotate(180deg)';
}, function (props) {
  return props.width;
}, function (props) {
  return props.height;
});

var ChevronIcon = function ChevronIcon(props) {
  return React__default.createElement(IconContainer, {
    dropdownOpen: props.dropdownOpen,
    xmlns: 'http://www.w3.org/2000/svg',
    width: props.iconProps && props.iconProps.width ? props.iconProps.width : 12,
    height: props.iconProps && props.iconProps.height ? props.iconProps.height : 12,
    viewBox: '0 0 12.453 7.12'
  }, React__default.createElement("path", {
    id: 'ic_chevron_up',
    d: 'M6.229,2.146l4.709,4.712a.886.886,0,0,0,1.257,0,.9.9,0,0,0,0-1.261L6.859.259A.888.888,0,0,0,5.632.233L.26,5.594A.89.89,0,0,0,1.516,6.855Z',
    fill: props.iconProps && props.iconProps.color ? props.iconProps.color : 'black'
  }));
};

var _templateObject$1;
var StyledCountryFlag = styled.img(_templateObject$1 || (_templateObject$1 = _taggedTemplateLiteralLoose(["\n  border-radius: ", ";\n\n  width: ", ";\n  height: ", ";\n  margin-right: 5px;\n"])), function (props) {
  return props.flagProps && props.flagProps.rounded ? '50%' : '5px';
}, function (props) {
  return props.dropdownItemProps.flagWidth ? props.dropdownItemProps.flagWidth : '24px';
}, function (props) {
  return props.dropdownItemProps.flagHeight ? props.dropdownItemProps.flagHeight : '24px';
});

var CountryFlag = function CountryFlag(props) {
  return React__default.createElement(StyledCountryFlag, Object.assign({}, props));
};

var _templateObject$2;
var CountryListItem = styled.button(_templateObject$2 || (_templateObject$2 = _taggedTemplateLiteralLoose(["\n  display: flex;\n  background-color: transparent;\n  border: none;\n  align-items: center;\n  cursor: pointer;\n  width: 100%;\n  padding: 0.5rem 0.25rem;\n  transition: all 0.3s;\n  :hover {\n    background-color: whitesmoke;\n  }\n"])));

var CountryItem = function CountryItem(props) {
  return React__default.createElement(CountryListItem, Object.assign({}, props.restDropdownProps, {
    key: props.index,
    onClick: function onClick() {
      return props.handleSelect && !props.disableCountrySelect && props.handleSelect(props.country);
    }
  }), React__default.createElement(CountryFlag, {
    flagProps: props.flagProps,
    dropdownItemProps: props.dropdownItemProps,
    src: props.country.flags.png,
    alt: ''
  }), React__default.createElement("div", null, props.country.name.common));
};

var _excluded = ["className"];

var _templateObject$3, _templateObject2;
var CountryDropdownContainer = styled.div(_templateObject$3 || (_templateObject$3 = _taggedTemplateLiteralLoose([""])));
var CountryListContainer = styled.div(_templateObject2 || (_templateObject2 = _taggedTemplateLiteralLoose(["\n  position: absolute;\n  top: 100%;\n  left: 0;\n  min-width: 200px;\n  height: 200px;\n  overflow-y: scroll;\n  scrollbar-width: 0;\n  background-color: white;\n  border: 1px solid #b5b5c3;\n  border-bottom-left-radius: 10px;\n  border-bottom-right-radius: 10px;\n  ::-webkit-scrollbar {\n    display: none;\n  }\n"])));

var CountryDropdown = function CountryDropdown(props) {
  var countries = props.countries,
      handleSelect = props.handleSelect,
      dropdownItemProps = props.dropdownItemProps;

  var restdropdownItemProps = _objectWithoutPropertiesLoose(dropdownItemProps, _excluded);

  var dropdownRef = useRef(null);
  useEffect(function () {
    document.addEventListener('click', handleOutsideClick, true);
    return function () {
      document.removeEventListener('click', handleOutsideClick, false);
    };
  }, []);

  var handleOutsideClick = function handleOutsideClick(e) {
    if (dropdownRef.current && !dropdownRef.current.contains(e.target)) {
      props.setDropdownopen(false);
    }
  };

  return React__default.createElement("div", {
    ref: dropdownRef
  }, React__default.createElement(CountryDropdownContainer, {
    className: classNames('dropdown-container')
  }, React__default.createElement(CountryListContainer, {
    style: {}
  }, countries.length > 0 ? React__default.createElement(React__default.Fragment, null, countries.map(function (country, index) {
    return React__default.createElement(CountryItem, {
      key: index,
      flagProps: props.flagProps,
      restDropdownProps: restdropdownItemProps,
      dropdownItemProps: dropdownItemProps,
      handleSelect: !props.disableCountrySelect ? handleSelect : null,
      country: country,
      index: index,
      disableCountrySelect: props.disableCountrySelect
    });
  })) : React__default.createElement("div", null, "loading..."))));
};

var _excluded$1 = ["className", "testId"];

var _templateObject$4, _templateObject2$1, _templateObject3, _templateObject4;
var SelectedCountryContainer = styled.div(_templateObject$4 || (_templateObject$4 = _taggedTemplateLiteralLoose(["\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n"])));
var DialCode = styled.span(_templateObject2$1 || (_templateObject2$1 = _taggedTemplateLiteralLoose(["\n  margin-right: 5px;\n"])));
var CountrySelectorContainer = styled.div(_templateObject3 || (_templateObject3 = _taggedTemplateLiteralLoose(["\n  position: relative;\n  padding: 0.5rem 1rem;\n  cursor: pointer;\n  border: none;\n  border-right: 1px solid\n    ", ";\n  border-top-left-radius: 5px;\n  border-bottom-left-radius: 5px;\n  background-color: ", ";\n"])), function (props) {
  return props.containerProps.borderColor ? props.containerProps.borderColor : '#b5b5c3';
}, function (props) {
  return props.dropdownProps.dropdownButtonColor ? props.dropdownProps.dropdownButtonColor : '#eff4f7';
});
var SelectedCountryInnerContainer = styled.div(_templateObject4 || (_templateObject4 = _taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n"])));

var CountrySelector = function CountrySelector(_ref) {
  var _ref$dropdownButtonPr = _ref.dropdownButtonProps,
      dropdownButtonProps = _ref$dropdownButtonPr === void 0 ? {} : _ref$dropdownButtonPr,
      _ref$dropdownItemProp = _ref.dropdownItemProps,
      dropdownItemProps = _ref$dropdownItemProp === void 0 ? {} : _ref$dropdownItemProp,
      _ref$containerProps = _ref.containerProps,
      containerProps = _ref$containerProps === void 0 ? {} : _ref$containerProps,
      defaultCountry = _ref.defaultCountry,
      flagProps = _ref.flagProps,
      selectedCountry = _ref.selectedCountry,
      setselectedCountry = _ref.setselectedCountry,
      disableCountrySelect = _ref.disableCountrySelect;

  var className = dropdownButtonProps.className,
      testId = dropdownButtonProps.testId,
      restDropdownProps = _objectWithoutPropertiesLoose(dropdownButtonProps, _excluded$1);

  var _useState = useState(false),
      dropdownOpen = _useState[0],
      setdropdownOpen = _useState[1];

  var _useState2 = useState([]),
      countries = _useState2[0],
      setcountries = _useState2[1];

  var _useState3 = useState(false),
      isCountriesLoading = _useState3[0],
      setisCountriesLoading = _useState3[1];

  useEffect(function () {
    if (!isCountriesLoading && countries.length > 0 && defaultCountry && defaultCountry.length > 0) {
      var foundCountry = countries.find(function (country) {
        return country.cca2 === defaultCountry.toUpperCase();
      });

      if (foundCountry) {
        setselectedCountry({
          name: foundCountry.name.common,
          dialCode: foundCountry.idd.root + foundCountry.idd.suffixes[0],
          flagURL: foundCountry.flags.png
        });
      }
    }
  }, [defaultCountry, countries, isCountriesLoading]);

  var handleClick = function handleClick() {
    if (disableCountrySelect === false) setdropdownOpen(!dropdownOpen);
  };

  var handleSelect = function handleSelect(country) {
    setselectedCountry({
      name: country.name.common,
      dialCode: country.idd.root + country.idd.suffixes[0],
      flagURL: country.flags.png
    });
  };

  useEffect(function () {
    setisCountriesLoading(true);
    axios.get('https://restcountries.com/v3.1/all').then(function (res) {
      setcountries(res.data.sort(function (a, b) {
        return a.name.common.localeCompare(b.name.common);
      }));
      setisCountriesLoading(false);
    });
  }, []);
  return React__default.createElement(CountrySelectorContainer, Object.assign({
    onClick: function onClick(e) {
      handleClick();
      dropdownButtonProps.onClick && dropdownButtonProps.onClick(e);
    },
    "data-test-id": testId
  }, restDropdownProps, {
    className: classNames(className),
    containerProps: containerProps,
    dropdownProps: dropdownButtonProps
  }), React__default.createElement("div", {
    onClick: !disableCountrySelect ? handleClick : function () {}
  }, React__default.createElement(SelectedCountryContainer, null, selectedCountry.name.length > 0 ? React__default.createElement(SelectedCountryInnerContainer, null, React__default.createElement(CountryFlag, {
    flagProps: flagProps,
    dropdownItemProps: dropdownItemProps,
    src: selectedCountry.flagURL
  }), React__default.createElement(DialCode, null, selectedCountry.dialCode)) : dropdownButtonProps.placeholder ? dropdownButtonProps.placeholder : 'Select', !disableCountrySelect && React__default.createElement(ChevronIcon, {
    iconProps: dropdownButtonProps.iconProps,
    dropdownOpen: dropdownOpen
  }))), dropdownOpen && React__default.createElement(CountryDropdown, {
    setDropdownopen: setdropdownOpen,
    flagProps: flagProps,
    countries: countries,
    handleSelect: !disableCountrySelect ? handleSelect : null,
    selectedCountry: selectedCountry,
    dropdownItemProps: dropdownItemProps,
    disableCountrySelect: disableCountrySelect
  }));
};

var styles = {"input-container":"_1Yg3U"};

var _excluded$2 = ["dialCode", "onInputChange", "defaultValue", "testId"];

var Input = function Input(props) {
  var dialCode = props.dialCode,
      onInputChange = props.onInputChange,
      testId = props.testId,
      rest = _objectWithoutPropertiesLoose(props, _excluded$2);

  return React__default.createElement("input", Object.assign({}, rest, {
    type: 'number',
    "data-test-id": testId,
    className: classNames(styles['input-container']),
    onChange: function onChange(e) {
      onInputChange && onInputChange({
        dialCode: dialCode ? dialCode : '',
        phoneNumber: e.target.value
      });
    }
  }));
};

var _excluded$3 = ["className"];

var _templateObject$5;
var AppContainer = styled.div(_templateObject$5 || (_templateObject$5 = _taggedTemplateLiteralLoose(["\n  display: flex;\n  align-items: center;\n  border: 1px solid\n    ", ";\n  border-radius: 5px;\n"])), function (props) {
  return props.containerProps.borderColor ? props.containerProps.borderColor : '#b5b5c3';
});
var PhoneInput = function PhoneInput(_ref) {
  var _ref$containerProps = _ref.containerProps,
      containerProps = _ref$containerProps === void 0 ? {} : _ref$containerProps,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      _ref$dropdownButtonPr = _ref.dropdownButtonProps,
      dropdownButtonProps = _ref$dropdownButtonPr === void 0 ? {} : _ref$dropdownButtonPr,
      onChange = _ref.onChange,
      onInputChange = _ref.onInputChange,
      defaultCountry = _ref.defaultCountry,
      _ref$flagProps = _ref.flagProps,
      flagProps = _ref$flagProps === void 0 ? {
    rounded: false
  } : _ref$flagProps,
      _ref$disableCountrySe = _ref.disableCountrySelect,
      disableCountrySelect = _ref$disableCountrySe === void 0 ? false : _ref$disableCountrySe,
      prepend = _ref.prepend;

  var containerClassName = containerProps.className,
      restContainerProps = _objectWithoutPropertiesLoose(containerProps, _excluded$3);

  var _React$useState = useState({
    name: '',
    dialCode: '',
    flagURL: ''
  }),
      selectedCountry = _React$useState[0],
      setselectedCountry = _React$useState[1];

  return createElement(AppContainer, Object.assign({
    containerProps: containerProps
  }, restContainerProps, {
    className: classNames(containerClassName ? containerClassName : '')
  }), createElement(CountrySelector, {
    selectedCountry: selectedCountry,
    setselectedCountry: setselectedCountry,
    flagProps: flagProps,
    defaultCountry: defaultCountry,
    onChange: onChange,
    dropdownButtonProps: dropdownButtonProps,
    disableCountrySelect: disableCountrySelect,
    containerProps: containerProps
  }), createElement(Input, Object.assign({
    onInputChange: onInputChange,
    dialCode: selectedCountry.dialCode
  }, inputProps)), prepend && prepend);
};

export { PhoneInput };
//# sourceMappingURL=index.modern.js.map
